# libpythonpro
Módulo para exemplificar construção de projetos python no curso PyTools

Nesse curso é ensinado como contrubuir com projetos de código aberto

Link do curso [Python Pro](https://google.com.br/)

[![Updates](https://pyup.io/repos/github/anthonysilvaa/libpythonpro/shield.svg)](https://pyup.io/repos/github/anthonysilvaa/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/anthonysilvaa/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/anthonysilvaa/libpythonpro/)

Para instalar:

```console
python -3 -m venv .venv
.venv/Scripts/activate
pip install -r requirements-dev.txt

```

Para conferir qualidade do código:

```
flake8

```